@@ -9,12 +9,13 @@ import time
 import shutil
 import os.path
 import subprocess
+from argparse import ArgumentParser
 
-COVERAGE = os.environ.get("XPRA_TEST_COVERAGE", "1") == "1"
+TEST_COVERAGE = os.environ.get("XPRA_TEST_COVERAGE", "1") == "1"
+COVERAGE = os.environ.get("COVERAGE", shutil.which("coverage") or shutil.which("python3-coverage"))
 
 
-def getargs():
-    from argparse import ArgumentParser
+def getargs() -> ArgumentParser:
     P = ArgumentParser()
     P.add_argument('--skip-fail', action='append', default=[])
     P.add_argument('--skip-slow', action='append', default=[])
@@ -23,14 +24,14 @@ def getargs():
     return P
 
 
-def main(args):
-    if COVERAGE:
+def main(args) -> int:
+    if TEST_COVERAGE:
         # pylint: disable=import-outside-toplevel
         #only include xpra in the report,
         #and to do that, we need the path to the module (weird):
         import xpra
         xpra_mod_dir = os.environ.get("XPRA_MODULE_DIR") or os.path.dirname(xpra.__file__)
-        run_cmd = ["coverage", "run", "--parallel-mode", "--include=%s/*" % xpra_mod_dir]
+        run_cmd = [COVERAGE, "run", "--parallel-mode", "--include=%s/*" % xpra_mod_dir]
         #make sure we continue to use coverage to run sub-commands:
         xpra_cmd = os.environ.get("XPRA_COMMAND", shutil.which("xpra")) or "xpra"
         if xpra_cmd.find("coverage") < 0:
@@ -49,11 +50,11 @@ def main(args):
     sys.path.append(unittests_dir)
 
     #now look for tests to run
-    def write(msg):
+    def write(msg) -> None:
         sys.stdout.write(f"{msg}\n")
         sys.stdout.flush()
 
-    def run_file(p):
+    def run_file(p: str) -> int:
         #ie: "~/projects/Xpra/trunk/src/tests/unit/version_util_test.py"
         tfile = os.path.join(unittests_dir, p)
         if not (os.path.isfile(tfile) and tfile.startswith(unittests_dir) and tfile.endswith("test.py")):
@@ -83,7 +84,7 @@ def main(args):
         write(f"ran {name} in {T1 - T0:.2f} seconds\n")
         return v
 
-    def add_recursive(d):
+    def add_recursive(d: str) -> int:
         paths = os.listdir(d)
         ret = 0
         for path in paths:
